/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _SHADER_OBJECT_HPP_
#define _SHADER_OBJECT_HPP_

#include <GL/glew.h>

#include <fstream>
#include <cassert>
using namespace std;

/**
 * The base class for Vertex and Fragment Shaders.
 *
 * The base class handles the loading and deletion of shader objects. When loading a shader the
 * only difference between the vertex and fragment shaders is during the creation of the handle.
 * So the subclasses are fairly trivial with just different constructors.
 *
 * \author Don Olmstead
 * \version 1.0
 */
class ShaderObject
{
	protected:
		ShaderObject();

	public:
		virtual ~ShaderObject();

		void loadShader(const char* fileName);

		GLhandleARB& getShader();

	protected:
		char* getFileContents(const char* fileName);

		GLhandleARB shader;
} ;

#endif
